#  tests for liknorm-py-1.2.4-py37h3a3b6f7_1 (this is a generated file);
print('===== testing package: liknorm-py-1.2.4-py37h3a3b6f7_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import sys

import liknorm

sys.exit(liknorm.test())
#  --- run_test.py (end) ---

print('===== liknorm-py-1.2.4-py37h3a3b6f7_1 OK =====');
print("import: 'liknorm'")
import liknorm

